.. _make-small-edits-via-github:

===========================
Make small edits via GitHub
===========================

For small edits to the documentation, use the GitHub web interface.

#.  On every page in documentation, on the right-hand side, there is a link :guilabel:`Edit on GitHub`.
    When you click that link, you'll be taken to GitHub's web interface where you can edit files.

    Alternatively, for narrative documentation files, you can navigate into the `docs <https://github.com/collective/icalendar/tree/main/docs>`_ directory to find the source file to edit.
    For :doc:`API reference documentation files </reference/api/icalendar>`, you can instead navigate into the `src <https://github.com/collective/icalendar/tree/main/docs>`_ directory.
    For either file type, you can then click the :guilabel:`pencil icon` to edit the file in the browser.

    .. image:: /_static/edit-pencil-icon.png
        :alt: GitHub Edit this file

#.  Make edits.
    When done click :guilabel:`Commit changes…`.
    A modal dialog pops up.
#.  In the modal dialog:

    -   Add a commit message.
    -   Optionally add an extended description.
    -   Select :guilabel:`Create a new branch for this commit and start a pull request`.
    -   Enter a descriptive name for the new branch.
    -   Click :guilabel:`Propose changes`.

#.  Make your pull request against the ``main`` branch of the repository.
#.  Members who subscribe to the repository will receive a notification and review your request.
#.  Request a review from other team members.


